@@ -538,12 +538,12 @@ def _delete__notebook_checkpoint(config, checkpoint_id, path):
 
 
 @gen.coroutine
-def _list_current_child_files_and_folders(config, prefix):
-    return (yield _get_all_keys(config, prefix, '/'))
+def _list_current_child_files_and_folders(config, key_prefix):
+    return (yield _get_all_keys(config, key_prefix, '/'))
 
 @gen.coroutine
-def _list_all_successor_keys(config, prefix):
-    return (yield _get_all_keys(config, prefix, ''))[0]
+def _list_all_successor_keys(config, key_prefix):
+    return (yield _get_all_keys(config, key_prefix, ''))[0]
 
 @gen.coroutine
 def _restore_notebook_checkpoint(config, checkpoint_id, path):
@@ -602,18 +602,18 @@ def _copy_notebook(config, from_path, to_path):
 
 
 @gen.coroutine
-def _get_all_keys(config, prefix, delimiter):
+def _get_all_keys(config, key_prefix, delimiter):
 
     max_keys = 1000
 
     @gen.coroutine
     def _list_first_page():
-        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys)
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys)
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
-        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys, token)
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
@@ -661,23 +661,23 @@ PUT_HELPERS = {
     ('directory', 'json'): _save_folder,
     ('file', 'text'): _save_text_file
 }
-#------------------------------------------
+
 @gen.coroutine
-def _delete_key_object(config, curr_key):
-    yield _delete_object(config, config.bucket_name, curr_key)
+def _delete_key_object(config, key):
+    yield _delete_object(config, config.bucket_name, key)
 
 
 @gen.coroutine
-def _copy_key_object(config, prev_key, curr_key):
-    yield _copy_object(config, config.bucket_name, prev_key, curr_key)
+def _copy_key_object(config, old_key, new_key):
+    yield _copy_object(config, config.bucket_name, old_key, new_key)
 
 
 def _get_copy_key(curr_key):
     if curr_key.endswith(FOLDER_SEPERATOR):
         return (curr_key.count('/'),0)
     else:
-        return (curr_key.count('/'),1)
-    # return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
+        return (curr_key.count('/'),0)
+    return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
 def _delete_copy_key(key):
     copy_keys = []
